@@ -184,7 +184,7 @@ class CrossValidation(BaseExperiment):
         return cv_indices
 
 
-    def get_hparam_info(self)->dict:
+    def get_hparam_info(self)->Dict:
         r"""Get informations of ``parameters``.
 
         Returns:
@@ -205,7 +205,7 @@ class CrossValidation(BaseExperiment):
 
         return hparam_info
 
-    def get_hparams_dict_list(self)->List[dict]:
+    def get_hparams_dict_list(self)->List[Dict]:
         r"""Get set of hyperparameter candidates.
 
         Returns:
@@ -266,7 +266,7 @@ class CrossValidation(BaseExperiment):
         X_test : Optional["np.ndarray"] = None,
         y_test : Optional["np.ndarray"] = None,
         test_size : float = 0.01
-    )->Union["pl.LightningDataModule", tuple["np.ndarray","np.ndarray","np.ndarray","np.ndarray","np.ndarray","np.ndarray"]]:
+    )->Union["pl.LightningDataModule", Tuple["np.ndarray","np.ndarray","np.ndarray","np.ndarray","np.ndarray","np.ndarray"]]:
         r"""Gets datamodule.
         
         Returns:
@@ -306,7 +306,7 @@ class CrossValidation(BaseExperiment):
 
         return data_module
 
-    def search(self)->tuple[Union["pl.LightningModule", "BaseEstimator"], dict]:
+    def search(self)->Tuple[Union["pl.LightningModule", "BaseEstimator"], Dict]:
         r"""Performs cross-validation.
 
         Returns:
