@@ -636,7 +636,7 @@ class BaseProject:
     def search_standard(
         self,
         val_metric : str = 'val/acc'
-    )->tuple["np.ndarray", dict[str,int], dict[str,int]]: 
+    )->Tuple["np.ndarray", dict[str,int], dict[str,int]]: 
         r"""Search method for finding the model type/structure with best validation performance.
 
         Args:
@@ -702,7 +702,7 @@ class BaseProject:
         self,
         model_type : Union["pl.LightningModule", "BaseEstimator"],
         val_metric : str = 'val/acc'
-    )->tuple["np.ndarray",dict[str,int]]:
+    )->Tuple["np.ndarray",Dict[str,int]]:
         r"""Search method for finding validation performances for a specific model type.
 
         Args:
@@ -763,7 +763,7 @@ class BaseProject:
         model_type : Union["pl.LightningModule", "BaseEstimator"], 
         val_metric : str = 'val/acc',
         **hparams
-    )->tuple["np.ndarray", str]:
+    )->Tuple["np.ndarray", str]:
         r"""Search method for finding validation performances of a specific model structure.
 
         Args:
@@ -819,7 +819,7 @@ class BaseProject:
     def search_all_models(
         self,
         val_metric : str = 'val/acc'
-    )->tuple["np.ndarray", List[str]]:
+    )->Tuple["np.ndarray", List[str]]:
         r"""Method for searching validation performances of all saved models.
 
         Args:
@@ -981,7 +981,7 @@ class Project(BaseProject):
             self,
             val_metric : str = 'val/acc',
             plt_title : Optional[str] = None
-        )->tuple["np.ndarray",dict[str,dict[str,int]]]: # (validation performances, information)
+        )->Tuple["np.ndarray",Dict[str,Dict[str,int]]]: # (validation performances, information)
             r"""Plots the best validation performance for each ``Experiment``.
 
             Args:
@@ -1032,7 +1032,7 @@ class Project(BaseProject):
         self,
         val_metric : str = 'val/acc',
         plt_title : Optional[str] = None
-    )->tuple["np.ndarray",dict[str,dict[str,int]]]: # (validation performances, information)
+    )->Tuple["np.ndarray",Dict[str,Dict[str,int]]]: # (validation performances, information)
         r"""Plots pie graphs showing the frequencies of 1)best model type and 2)best model structure for each ``Experiment``.
 
         Args:
@@ -1085,7 +1085,7 @@ class Project(BaseProject):
         model_type : Union["pl.LightningModule","BaseEstimator"],
         val_metric : str = "val/acc",
         plt_title : Optional[str] = None
-    )->tuple["np.ndarray", List[str], dict[str,dict[str,int]]]: 
+    )->Tuple["np.ndarray", List[str], Dict[str,Dict[str,int]]]: 
         r"""Plots validation performances across different random states for a given model type.
 
         Args:
@@ -1138,7 +1138,7 @@ class Project(BaseProject):
         val_metric : str = "val/acc",
         plt_title : Optional[str] = None,
         **hparams
-    )->tuple["np.ndarray",List[str]]: 
+    )->Tuple["np.ndarray",List[str]]: 
         r"""Plots validation performances across different random states for a given model structure.
 
         Args:
@@ -1210,7 +1210,7 @@ class Project(BaseProject):
         self,
         val_metric : str = "val/acc",
         plt_title : Optional[str] = None
-    )->tuple["np.ndarray", List[str]]:
+    )->Tuple["np.ndarray", List[str]]:
         r"""Plots validation performances across different random states for all model structures saved. 
         
         Will plot 1)line graphs and 2)box plots.
